@@ -21,7 +21,6 @@ class Message(BaseAppInput):
     role: ContextMessageRole
     content: str
 
-
 class ContextMessage(BaseAppInput):
     role: ContextMessageRole = Field(
         description="the role of the message. user, assistant, or system",
@@ -33,6 +32,10 @@ class ContextMessage(BaseAppInput):
         description="the image file of the message",
         default=None
     )
+    tool_calls: Optional[List[Dict[str, Any]]] = Field(
+        description="the tool calls of the message",
+        default=None
+    )
 
 class BaseLLMInput(BaseAppInput):
     """Base class with common LLM fields."""
@@ -53,8 +56,12 @@ class BaseLLMInput(BaseAppInput):
             ]
         ]
     )
+    role: ContextMessageRole = Field(
+        description="the role of the input text",
+        default=ContextMessageRole.USER
+    )
     text: str = Field(
-        description="the user prompt to use for the model",
+        description="the input text to use for the model",
         examples=[
             "write a haiku about artificial general intelligence"
         ]
@@ -230,6 +237,13 @@ def build_messages(
         images = [msg.image for msg in messages if msg.image]
         image = images[0] if images else None # TODO: handle multiple images
         return ContextMessage(role=messages[0].role, text=text, image=image)
+    
+    def merge_tool_calls(messages: List[ContextMessage]) -> List[Dict[str, Any]]:
+        tool_calls = []
+        for msg in messages:
+            if msg.tool_calls:
+                tool_calls.extend(msg.tool_calls)
+        return tool_calls
 
     user_input_text = ""
     if hasattr(input_data, "text"):
@@ -241,7 +255,8 @@ def build_messages(
         user_input_image = input_data.image
         multipart = multipart or input_data.image is not None
 
-    user_msg = ContextMessage(role=ContextMessageRole.USER, text=user_input_text, image=user_input_image)
+    input_role = input_data.role if hasattr(input_data, "role") else ContextMessageRole.USER
+    user_msg = ContextMessage(role=input_role, text=user_input_text, image=user_input_image)
 
     input_data.context.append(user_msg)
 
@@ -255,14 +270,16 @@ def build_messages(
         else:
             messages.append({
                 "role": current_role,
-                "content": render_message(merge_messages(current_messages), allow_multipart=multipart)
+                "content": render_message(merge_messages(current_messages), allow_multipart=multipart),
+                "tool_calls": merge_tool_calls(current_messages)
             })
             current_messages = [msg]
             current_role = msg.role
     if len(current_messages) > 0:
         messages.append({
             "role": current_role,
-            "content": render_message(merge_messages(current_messages), allow_multipart=multipart)
+            "content": render_message(merge_messages(current_messages), allow_multipart=multipart),
+            "tool_calls": merge_tool_calls(current_messages)
         })
 
     return messages
@@ -650,6 +667,7 @@ def stream_generate(
         last_activity = time.time()
         init_timeout = 30.0  # 30 seconds for initial response
         chunk_timeout = 10.0  # 10 seconds between chunks
+        chunks_begun = False
         
         try:
             # Wait for initial setup
@@ -680,7 +698,7 @@ def stream_generate(
                     pass
                 
                 # Check for timeout
-                if time.time() - last_activity > chunk_timeout:
+                if chunks_begun and time.time() - last_activity > chunk_timeout:
                     raise RuntimeError(f"No response from model for {chunk_timeout} seconds")
                 
                 # Get next chunk
@@ -705,6 +723,8 @@ def stream_generate(
                 if not timing.first_token_time:
                     timing.mark_first_token()
                 
+                chunks_begun = True
+                
                 # Update response state from chunk
                 response.update_from_chunk(chunk, timing)
                 
